@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
+# flake8: noqa
 
 """
 python-jamf
 Module to hit the Jamf API
 """
 
-from .api import API
+from . import convert, package, version
 from .admin import JamfAdmin as Admin
-from . import package
-from . import convert
+from .api import API
 from .records import *
-
-__version__ = "0.4.7"
\ No newline at end of file
