@@ -8,7 +8,7 @@ __author__ = "Sam Forester"
 __email__ = "sam.forester@utah.edu"
 __copyright__ = "Copyright (c) 2020 University of Utah, Marriott Library"
 __license__ = "MIT"
-__version__ = "1.2.4"
+__version__ = "1.2.5"
 
 import getpass
 import logging
@@ -118,6 +118,12 @@ the "./jamf/setconfig.py" script.
                 self.password = getpass.getpass()
         elif not self.hostname and not self.username and not self.password:
             raise Exception("No jamf config file could be found and prompt is off.")
+        if not self.hostname.startswith("https://") and not self.hostname.startswith(
+            "http://"
+        ):
+            raise Exception(
+                f"Hostname ({self.hostname}) does not start with 'https://' or 'http://'"
+            )
 
     def save(self, config_path=None):
         keyring.set_password(self.hostname, self.username, self.password)
@@ -133,4 +139,9 @@ the "./jamf/setconfig.py" script.
 
 
 def prompt_hostname():
-    return input("Hostname (don't forget https:// and :8443): ")
+    valid = False
+    while not valid:
+        hostname = input("Hostname (don't forget https:// and :8443): ")
+        if hostname.startswith("https://") or hostname.startswith("http://"):
+            valid = True
+    return hostname
